package mschmidt.komo;
/*
 * Shows database related information.
 */

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;

public class DbInfoDialog extends Dialog {

	// Initialize the dialog variables.
	private static final int CLIPBOARD_ID = IDialogConstants.NO_TO_ALL_ID + 1;  

	private Text infoText;
	
	private String infoString;
	
	/**
	 * Constructor that creates the dialog.
	 * 
	 * @param parentShell - this Dialog's parent
	 * @param stInfo - The string that this dialog will display.
	 */
	public DbInfoDialog(final Shell parentShell, final String stInfo) {
		super(parentShell);
		infoString = stInfo;
	}

	/**
	 * Create contents of the dialog.
	 * 
	 * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(
	 * org.eclipse.swt.widgets.Composite)
	 * @param parent - the parent composite
	 * @return container - returns the constructed container
	 */
	@Override
	protected final Control createDialogArea(final Composite parent) {
		Composite container = (Composite) super.createDialogArea(parent);

		infoText = new Text(
				container, SWT.V_SCROLL | SWT.BORDER | SWT.H_SCROLL);
		infoText.setEditable(false);
		infoText.setBackground(Display.getCurrent().getSystemColor(
				SWT.COLOR_WHITE));
		infoText.setText(infoString);
		infoText.setLayoutData(
			new GridData(GridData.FILL, GridData.CENTER, true, true));

		return container;
	}

	/**
	 * Create contents of the button bar, including a 
	 * custom Copy to Clipboard button.
	 * @see org.eclipse.jface.dialogs.Dialog#createButtonsForButtonBar(
	 * org.eclipse.swt.widgets.Composite)
	 * @param parent - the parent composite
	 */
	@Override
	protected final void createButtonsForButtonBar(final Composite parent) {
		createButton(parent, CLIPBOARD_ID, "Copy to Clipboard", false);
		createButton(parent, IDialogConstants.CANCEL_ID, 
				IDialogConstants.CLOSE_LABEL, true);
	}

	/**
	 * Set the initial size of the dialog.
	 * @see org.eclipse.jface.window.Window#getInitialSize()
	 * @return Point - the initial size
	 */
	@Override
	protected final Point getInitialSize() {
		return new Point(500, 375);
	}
	
	/* (non-Javadoc)
	 * Method that configures the shell.  Note that this is a generic dialog 
	 * that can present information for several program components, 
	 * so the title and image are set by the calling methods.
	 * 
	 * @see org.eclipse.jface.window.Window#configureShell(
	 * org.eclipse.swt.widgets.Shell)
	 */
	@Override
	protected final void configureShell(final Shell newShell) {
		super.configureShell(newShell);
	}

	/* (non-Javadoc)
	 * Override method to add maximize button.
	 * 
	 * @see org.eclipse.jface.window.Window#setShellStyle(int)
	 */
	@Override
	protected final void setShellStyle(final int newShellStyle) {
		super.setShellStyle(SWT.DIALOG_TRIM | SWT.MAX);
	}

	/*
	 *  (non-Javadoc)
	 *  Copy contents of the text window to the clipboard when the 
	 *  Copy to Clipboard is clicked.
	 * @see org.eclipse.jface.dialogs.Dialog#buttonPressed(int)
	 */
	@Override
	protected void buttonPressed(int buttonID) {
		if (buttonID == CLIPBOARD_ID) {
			infoText.selectAll();
			infoText.copy();
			infoText.clearSelection();
		} else {
			super.buttonPressed(buttonID);
			
		}
	}

}

